# wbpNamespace

Namespace plugin for Workbench applications

## Installation

```shell
pip install wbpNamespace
```

## Documentation

For details read the [Documentation](https://workbench2.gitlab.io/workbench-plugins/wbpnamespace/).